InformationSizeTransformation class

A transformation to convert an InformationSize to a human-readable String by using an InformationSizeFormat.

See also:

Inheritance

Constructors

InformationSizeTransformation({String pattern = defaultValuePattern, Set<InformationUnit> permissibleValueUnits = InformationUnits.iecBytes})
Creates an InformationSizeTransformation that will format values using the specified pattern, only using permissibleValueUnits.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
pattern → String
The pattern passed through to the InformationSizeFormat.
final
permissibleValueUnits → Set<InformationUnit>
The permissible value units.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transform(InformationSize input, String locale) → String
Transforms input into an instance of U using the provided locale.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited