QuantityRateTransformation class
A transformation to convert a QuantityRate to a human-readable String by using a QuantityRateFormat.
See also:
- Inheritance
-
- Object
- Transformation<
QuantityRate, String> - QuantityRateTransformation
Constructors
-
QuantityRateTransformation({String pattern = defaultRatePattern, Set<
QuantityUnit> permissibleValueUnits = QuantityUnits.all, Set<RateUnit> permissibleRateUnits = RateUnits.hourOrLess}) -
Creates a QuantityRateTransformation that will format values using the specified
pattern, only usingpermissibleValueUnitsandpermissibleRateUnits.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pattern → String
-
The pattern passed through to the QuantityRateFormat.
final
-
permissibleRateUnits
→ Set<
RateUnit> -
The permissible rate units.
final
-
permissibleValueUnits
→ Set<
QuantityUnit> -
The permissible value units.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
QuantityRate input, String locale) → String -
Transforms
inputinto an instance ofUusing the providedlocale.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited