TemperatureTransformation class

A transformation to convert an Temperature to a human-readable String by using a TemperatureFormat.

See also:

Inheritance

Constructors

TemperatureTransformation({String pattern = defaultValuePattern, Set<TemperatureUnit> permissibleValueUnits = TemperatureUnits.celsius})
Creates a TemperatureTransformation that will format values using the specified pattern, only using permissibleValueUnits.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
pattern → String
The pattern passed through to the TemperatureFormat.
final
permissibleValueUnits → Set<TemperatureUnit>
The permissible value units.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transform(Temperature input, String locale) → String
Transforms input into an instance of U using the provided locale.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited