TimeRateTransformation class

A transformation to convert an TimeRate to a human-readable String by using a TimeRateFormat.

See also:

Inheritance

Constructors

TimeRateTransformation({String pattern = defaultRatePattern, Set<TimeUnit> permissibleValueUnits = TimeUnits.common, Set<RateUnit> permissibleRateUnits = RateUnits.hourOrLess})
Creates a TimeRateTransformation that will format values using the specified pattern, only using permissibleValueUnits and permissibleRateUnits.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
pattern → String
The pattern passed through to the TimeRateFormat.
final
permissibleRateUnits → Set<RateUnit>
The permissible rate units.
final
permissibleValueUnits → Set<TimeUnit>
The permissible value units.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transform(TimeRate input, String locale) → String
Transforms input into an instance of U using the provided locale.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited