WeightRate class

Represents a rate of change in Weight.

Inheritance
Available extensions

Properties

hashCode → int
The hash code for this object.
no setterinherited
period → Duration
How often the value is occurring.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Weight
The underlying unit of measurement value.
finalinherited

Methods

humanize({String pattern = defaultRatePattern, Set<WeightUnit> permissibleValueUnits = WeightUnits.commonSi, Set<RateUnit> permissibleRateUnits = RateUnits.hourOrLess, String? locale}) → String

Available on WeightRate, provided by the WeightRateExtensions extension

Humanizes this WeightRate using the specified pattern, which is forwarded to a WeightRateTransformation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited