WeightRateTransformation class

A transformation to convert an WeightRate to a human-readable String by using a WeightRateFormat.

See also:

Inheritance

Constructors

WeightRateTransformation({String pattern = defaultRatePattern, Set<WeightUnit> permissibleValueUnits = WeightUnits.commonSi, Set<RateUnit> permissibleRateUnits = RateUnits.hourOrLess})
Creates a WeightRateTransformation that will format values using the specified pattern, only using permissibleValueUnits and permissibleRateUnits.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
pattern → String
The pattern passed through to the WeightRateFormat.
final
permissibleRateUnits → Set<RateUnit>
The permissible rate units.
final
permissibleValueUnits → Set<WeightUnit>
The permissible value units.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
transform(WeightRate input, String locale) → String
Transforms input into an instance of U using the provided locale.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited