Transformation<T, U> class
abstract
Facilitates transforming a value of type T to type U.
This abstraction is used to encapsulate the many transformations provided by the Humanizer library. The advantages of this abstraction include consistency and unification.
- Implementers
- ApproximateTimeTransformation
- AreaRateTransformation
- AreaTransformation
- CardinalWordsTransformation
- FunctionTransformation
- InformationRateTransformation
- InformationSizeTransformation
- LengthRateTransformation
- LengthTransformation
- OrdinalNumericalTransformation
- OrdinalWordsTransformation
- PluralityTransformation
- QuantityRateTransformation
- QuantityTransformation
- SymbolToHumanizedNameTransformation
- TemperatureRateTransformation
- TemperatureTransformation
- TimeRateTransformation
- TimeTransformation
- ToSentenceCaseTransformation
- ToTitleCaseTransformation
- TruncateToFixedLengthTransformation
- TruncateToFixedNonWhitespaceLengthTransformation
- TruncateToFixedWordLengthTransformation
- VolumeRateTransformation
- VolumeTransformation
- WeightRateTransformation
- WeightTransformation
- Available extensions
Constructors
- Transformation()
-
Creates an instance of Transformation.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
then(
Transformation< U, V> transformation) → Transformation<T, V> -
Available on Transformation<
Chains together two transformations where the output of the first transformation becomes the input of the second.T, U> , provided by the TransformationExtensions extension -
toString(
) → String -
A string representation of this object.
inherited
-
transform(
T input, String locale) → U -
Transforms
inputinto an instance ofUusing the providedlocale.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited